package de.fhw.komponentenarchitekturen.knauf.stateless.standaloneclient;

import javax.naming.InitialContext;

import de.fhw.komponentenarchitekturen.knauf.stateless.GeometricModelRemote;

/**
 * Standalone Client application for accessing the GeometricModel
 * stateless session bean.
 * 
 * @author Wolfgang Knauf
 * 
 */
public class GeometricModelApplicationClient
{
  /**
   * Main method. Performs a EJB access and finishes
   * 
   * @param args Command line arguments.
   */
  public static void main(String[] args)
  {
    try
    {
      GeometricModelRemote geometricModel;

      
      //InitialContext befllt sich komplett aus "jndi.properties"
      InitialContext context = new InitialContext();

      //Lookup durchfhren:
      //jboss-remote-naming:
      //geometricModel = (GeometricModelRemote) context.lookup("Stateless/StatelessEJB//GeometricModelBean!de.fhw.komponentenarchitekturen.knauf.stateless.GeometricModelRemote");
      //JNDI:
      geometricModel = (GeometricModelRemote) context.lookup("ejb:Stateless/StatelessEJB//GeometricModelBean!de.fhw.komponentenarchitekturen.knauf.stateless.GeometricModelRemote");
      
      //EJB aufrufen:
      double dblVolume = geometricModel.computeCuboidVolume(10, 5, 7);
      double dblSurface = geometricModel.computeCuboidSurface(10, 5, 7);

      System.out.println("Calculated volume: " + dblVolume + ", surface: " + dblSurface);
    }
    catch (Exception ex)
    {
      ex.printStackTrace();
    }
  }
}
